@@ -8,14 +8,11 @@
 #
 
 
-from mo_parsing import *
-from mo_parsing.enhancement import LookAhead
-from mo_parsing.tokens import LookBehind
 from mo_parsing.helpers import restOfLine
 from mo_parsing.whitespaces import NO_WHITESPACE, Whitespace
 
 from mo_sql_parsing.keywords import *
-from mo_sql_parsing.types import get_column_type, simple_types, time_functions
+from mo_sql_parsing.types import get_column_type, time_functions
 from mo_sql_parsing.utils import *
 from mo_sql_parsing.windows import window
 
@@ -105,7 +102,7 @@ def parser(literal_string, ident, sqlserver=False):
         ) / to_switch_call
 
         cast = (
-            Group(CAST("op") + LB + expr("params") + AS + simple_types("params") + RB)
+            Group(CAST("op") + LB + expr("params") + AS + column_type("params") + RB)
             / to_json_call
         )
 
@@ -183,7 +180,7 @@ def parser(literal_string, ident, sqlserver=False):
         create_array = (
             keyword("array")("op")
             + Optional(
-                Literal("<").suppress() + column_type("type") + Literal(">").suppress()
+                LT.suppress() + column_type("type") + GT.suppress()
             )
             + (
                 LB + delimited_list(Group(expr))("args") + RB
@@ -212,9 +209,9 @@ def parser(literal_string, ident, sqlserver=False):
         create_struct = (
             keyword("struct")("op")
             + Optional(
-                Literal("<").suppress()
+                LT.suppress()
                 + delimited_list(column_type)("types")
-                + Literal(">").suppress()
+                + GT.suppress()
             )
             + LB
             + delimited_list(Group((expr("value") + alias) / to_select_call))("args")
@@ -295,6 +292,12 @@ def parser(literal_string, ident, sqlserver=False):
                             LEFT_ASSOC,
                             to_offset,
                         ),
+                        (
+                            Literal(".").suppress() + simple_ident,
+                            1,
+                            LEFT_ASSOC,
+                            to_offset,
+                        ),
                         (window_clause, 1, LEFT_ASSOC, to_window_mod),
                         (
                             assign("filter", LB + WHERE + expr + RB),
